package sun.awt.image;

import sun.misc.SoftCache;
import java.awt.image.ImageObserver;
import java.util.Arrays;
import java.util.List;
import java.awt.Image;

public class MultiResolutionToolkitImage extends ToolkitImage implements MultiResolutionImage
{
    Image resolutionVariant;
    private static final int BITS_INFO = 56;
    
    public MultiResolutionToolkitImage(Image image, Image resolutionVariant) {
        super(image.getSource());
        this.resolutionVariant = resolutionVariant;
    }
    
    @Override
    public Image getResolutionVariant(int n, int n2) {
        return (n <= this.getWidth() && n2 <= this.getHeight()) ? this : this.resolutionVariant;
    }
    
    public Image getResolutionVariant() {
        return this.resolutionVariant;
    }
    
    @Override
    public List<Image> getResolutionVariants() {
        return Arrays.asList(new Image[] { this, this.resolutionVariant });
    }
    
    public static ImageObserver getResolutionVariantObserver(Image image, ImageObserver imageObserver, int n, int n2, int n3, int n4) {
        return getResolutionVariantObserver(image, imageObserver, n, n2, n3, n4, false);
    }
    
    public static ImageObserver getResolutionVariantObserver(Image image, ImageObserver imageObserver, int n, int n2, int n3, int n4, boolean b) {
        if (imageObserver == null) {
            return null;
        }
        synchronized (MultiResolutionToolkitImage.ObserverCache.INSTANCE) {
            ImageObserver imageObserver2 = (ImageObserver)MultiResolutionToolkitImage.ObserverCache.INSTANCE.get(imageObserver);
            if (imageObserver2 == null) {
                imageObserver2 = ((p3, n8, n10, n12, n13, n14)/* java.awt.Image,int,int,int,int,int, */ -> {
                    if ((n8 & 0x39) != 0x0) {
                        n13 = (n13 + 1) / 2;
                    }
                    if ((n8 & 0x3A) != 0x0) {
                        n14 = (n14 + 1) / 2;
                    }
                    if ((n8 & 0x38) != 0x0) {
                        n10 /= 2;
                        n12 /= 2;
                    }
                    if (p6) {
                        n8 &= ((ToolkitImage)p0).getImageRep().check(null);
                    }
                    return p1.imageUpdate(p0, n8, n10, n12, n13, n14);
                });
                MultiResolutionToolkitImage.ObserverCache.INSTANCE.put(imageObserver, imageObserver2);
            }
            return imageObserver2;
        }
    }
    
    private static class ObserverCache
    {
        static final SoftCache INSTANCE;
        
        static {
            INSTANCE = new SoftCache();
        }
    }
}
